type SampleInfos = {
    type: "video";
    name: "bbb_short";
    mime: "video/mp4";
    extension: "mp4";
    cdn: "https://raw.githubusercontent.com/cseitz/sample-files/main/assets/video/mp4/bbb_short.mp4";
    bytes: 788493;
};

type AssetInfo = {
    readonly mime: string;
    readonly name: string;
    readonly type: string;
    readonly bytes: number;
    readonly extension: string;
    readonly cdn: string;
};
declare class SampleFileAsset<const I extends AssetInfo> {
    /** The MIME type of the file */
    readonly mime: I['mime'];
    /** The name of the file (without its extension) */
    readonly name: I['name'];
    /** The type of media (image, video, etc) */
    readonly type: I['type'];
    /** Filesize */
    readonly bytes: I['bytes'];
    /** File extension */
    readonly extension: I['extension'];
    /** Github Raw link (used to download the file) */
    readonly cdn: I['cdn'];
    constructor(info: I);
    /** Retrieves the absolute path to the assets' parent directory */
    get __dirname(): string;
    /** Retrieves the absolute path to the asset
     * **WARNING**: The file will not be present if not yet downloaded. Utilize `path` instead of `__path`
     */
    get __path(): string;
    /** Checks if the file is downloaded */
    isDownloaded(): Promise<boolean>;
    /** Downloads the file from the CDN
     * - Returns the path to the file
     */
    download(): Promise<string>;
    /** Retrieves the path to the file
     * - Automatically downloads the file if it is not yet downloaded
     */
    get path(): Promise<string>;
    static filter(info?: ((asset: SampleFileAsset<SampleInfos>) => boolean) | Partial<SampleInfos>): SampleFileAsset<SampleInfos>[];
}

declare const sampleFiles: {
    readonly video: {
        readonly mp4: {
            readonly bbb_short: SampleFileAsset<{
                readonly mime: "video/mp4";
                readonly name: "bbb_short";
                readonly type: "video";
                readonly bytes: 788493;
                readonly extension: "mp4";
                readonly cdn: "https://raw.githubusercontent.com/cseitz/sample-files/main/assets/video/mp4/bbb_short.mp4";
            }>;
        };
    };
} & {
    /** Filter assets by the specified search */
    filter: typeof SampleFileAsset.filter;
};

export { sampleFiles };
