// build/asset.ts
import { createWriteStream } from "fs";
import { access, mkdir, stat, unlink } from "fs/promises";
import { get } from "https";
import { fileURLToPath } from "url";
import { dirname, resolve } from "path";
var ___filename = import.meta.url ? fileURLToPath(import.meta.url) : __filename;
var __dirname = dirname(___filename);
var allAssets = [];
var SampleFileAsset = class {
  /** The MIME type of the file */
  mime;
  /** The name of the file (without its extension) */
  name;
  /** The type of media (image, video, etc) */
  type;
  /** Filesize */
  bytes;
  /** File extension */
  extension;
  /** Github Raw link (used to download the file) */
  cdn;
  constructor(info) {
    Object.assign(this, info);
    allAssets.push(this);
  }
  /** Retrieves the absolute path to the assets' parent directory */
  get __dirname() {
    return resolve(__dirname + `/../local-assets/${this.type}/${this.extension}`);
  }
  /** Retrieves the absolute path to the asset
   * **WARNING**: The file will not be present if not yet downloaded. Utilize `path` instead of `__path`
   */
  get __path() {
    return `${this.__dirname}/${this.name}.${this.extension}`;
  }
  /** Checks if the file is downloaded */
  async isDownloaded() {
    const __path = this.__path;
    if (await access(__path, 0).then((o) => true).catch((o) => false)) {
      const stats = await stat(__path);
      if (stats.size == this.bytes) {
        return true;
      } else {
        await unlink(__path);
      }
    }
    return false;
  }
  /** Downloads the file from the CDN
   * - Returns the path to the file
   */
  async download() {
    const __path = this.__path;
    if (await this.isDownloaded()) {
      return __path;
    }
    await mkdir(this.__dirname, { recursive: true });
    const output = createWriteStream(__path);
    const label = `- Downloading Sample File (${this.cdn})`;
    console.time(label);
    await new Promise(async (resolve2) => {
      const url = new URL(this.cdn);
      const req = get({
        port: 443,
        host: url.hostname,
        path: url.pathname,
        rejectUnauthorized: false,
        headers: {
          "Accept": "*/*",
          "Range": `bytes=0-`
        }
      }, async (res) => {
        res.pipe(output);
        res.on("end", () => {
          resolve2(true);
        });
      });
      req.on("error", (o) => console.log(o));
      req.end();
    });
    output.close();
    if (await this.isDownloaded()) {
      console.timeEnd(label);
      return __path;
    }
    throw new Error(`Failed to download asset from "${this.cdn}"`);
  }
  /** Retrieves the path to the file
   * - Automatically downloads the file if it is not yet downloaded
   */
  get path() {
    return new Promise(async (resolve2, reject) => {
      resolve2(await this.download());
    });
  }
  static filter(info) {
    if (!info) {
      return [...allAssets];
    }
    return allAssets.filter(typeof info === "function" ? info : (o) => {
      for (const key in info) {
        if (o[key] !== info[key]) {
          return false;
        }
      }
      return true;
    });
  }
};

// build/_assets.ts
var assets = {
  "video": {
    "mp4": {
      "bbb_short": new SampleFileAsset({ "mime": "video/mp4", "name": "bbb_short", "type": "video", "bytes": 788493, "extension": "mp4", "cdn": "https://raw.githubusercontent.com/cseitz/sample-files/main/assets/video/mp4/bbb_short.mp4" })
    }
  }
};

// build/index.ts
var sampleFiles = Object.assign(assets, {
  /** Filter assets by the specified search */
  filter: SampleFileAsset.filter
});
export {
  sampleFiles
};
//# sourceMappingURL=index.js.map